@@ -34,8 +34,8 @@
 	if (!retval) {                                                  \
 		GnomeVFSResult result = pygnome_vfs_exception_check();  \
 		if ((signed)result >= 0) {                              \
-                        GILSTATE_RELEASE(state);                        \
                         PyErr_Clear();                                  \
+                        GILSTATE_RELEASE(state);                        \
 			return result;                                  \
 		} else if ((signed)result == -2) {                      \
 			PyErr_Print();                                  \
@@ -946,7 +946,7 @@ do_check_same_fs  (GnomeVFSMethod  *method,
 	PyGILState_STATE state;
 	
 	pymethod = get_method_from_uri(a);
-	if (!pymethod->move_func) {
+	if (!pymethod->check_same_fs_func) {
 		return GNOME_VFS_ERROR_NOT_SUPPORTED;
 	}
 
@@ -954,7 +954,7 @@ do_check_same_fs  (GnomeVFSMethod  *method,
 	pyuri_a = pygnome_vfs_uri_new(gnome_vfs_uri_ref(a));
 	pyuri_b = pygnome_vfs_uri_new(gnome_vfs_uri_ref(b));	
 	pycontext = context_new(context);
-	retval = PyObject_CallObject(pymethod->move_func,
+	retval = PyObject_CallObject(pymethod->check_same_fs_func,
 				     Py_BuildValue("(NNN)",
 						   pyuri_a,
 						   pyuri_b,
